Cryptographic Module Validation Program | CSRC
Author: Computer Security Division, Information Technology Laboratory, National Institute of Standards and Technology, U.S. Department of Commerce
Description: The MIP list contains cryptographic modules on which the CMVP is actively working. For a module to transition from Review Pending to In Review, the lab must first pay the NIST Cost Recovery fee, and then the report will be assigned as resources become...
Date: 2016-10-11

# You are viewing this page in an unauthorized frame window.

This is a potential security issue, you are being redirected to https://csrc.nist.gov

# Cryptographic Module Validation Program CMVP

### Modules In Process List

The MIP list contains cryptographic modules on which the CMVP is actively working. For a module to transition from Review Pending to In Review, the lab must first pay the NIST Cost Recovery fee, and then the report will be assigned as resources become available. The validation process is a joint effort between the CMVP, the laboratory and the vendor and therefore, for any given module, the action to respond could reside with the CMVP, the lab or the vendor. This list does not provide granularity into which entity has the action. If you would like more information for a specific cryptographic module or its schedule, please contact the vendor.

Last Updated: 2/18/2021

Module Name | Vendor Name | Standard | Status
--- | --- | --- | ---
Thunder Series TH-3040S, TH-5440S, TH-5840S and TH-7440S-11 | A10 Networks, Inc. | FIPS 140-2 | Review Pending
ADVA 10TCE-PCN-16GU+AES100G-F encryption module | ADVA Optical Networking SE | FIPS 140-2 | Review Pending
ADVA 9TCE-PCN-10GU+AES10G-F encryption module | ADVA Optical Networking SE | FIPS 140-2 | Review Pending
Advantech SQFlash FIPS Certified SSD | Advantech Co., Ltd. | FIPS 140-2 | Review Pending
AT-SBx908 Gen2, AT-x950, AT-x550, AT-x530 Secure Management Module | Allied Telesis | FIPS 140-2 | Coordination
AWS Key Management Service HSM | Amazon Web Services, Inc. | FIPS 140-2 | Review Pending
Apple corecrypto Kernel Space Module for ARM | Apple Inc. | FIPS 140-2 | Coordination
Apple corecrypto Kernel Space Module for Intel | Apple Inc. | FIPS 140-2 | Coordination
Apple corecrypto Module v11.1 [Intel, Kernel, Software] | Apple Inc. | FIPS 140-3 | Review Pending
Apple corecrypto Module v11.1 [Intel, User, Software] | Apple Inc. | FIPS 140-3 | Review Pending
Apple corecrypto User Space Module for ARM | Apple Inc. | FIPS 140-2 | Coordination
Apple corecrypto User Space Module for Intel | Apple Inc. | FIPS 140-2 | Coordination
Aegis Fortress L3 Cryptographic Module | Apricorn | FIPS 140-2 | Review Pending
Aegis Secure Key 3NX Cryptographic Module | Apricorn | FIPS 140-2 | Review Pending
Apricorn FIPS 140-2 Encryption System Gen 2 | Apricorn | FIPS 140-2 | Review Pending
Arista EOS Crypto Module | Arista Networks, Inc. | FIPS 140-2 | Review Pending
Aruba 7280 Controller with ArubaOS FIPS Firmware | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 | Review Pending
Aruba 9004 Series Gateway with ArubaOS FIPS Firmware | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 | In Review
Aruba AP-318, AP-344, AP-345, AP-374, AP-375, AP-377 and AP-387 Outdoor Access Points with ArubaOS FIPS Firmware | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 | Review Pending
Aruba AP-504, AP-505, AP-514, AP-515, AP-534, AP-535 and AP-555 Wireless Access Points with ArubaOS FIPS Firmware | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 | Coordination
Aruba IAP-303H, IAP-304, IAP-305, IAP-314, IAP-315, IAP-324, IAP-325, IAP-334, and IAP-335 Wireless Access Points with Aruba Instant Firmware | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 | Coordination
CRATON2/SECTON embedded V2X HSM | Autotalks Ltd. | FIPS 140-2 | Review Pending
TASS Crypto Engine | Beijing JN TASS Technology Co., Ltd. | FIPS 140-2 | Coordination
Cryptographic Server HSM | Beijing Lianshi Networks Technology Co.,Ltd. | FIPS 140-2 | Review Pending
BCM58200 Series: BCM58201, BCM58202 | Broadcom, Inc. | FIPS 140-2 | Review Pending
Ubuntu 18.04 Kernel Crypto API Cryptographic Module | Canonical Ltd. | FIPS 140-2 | Review Pending
Ubuntu 18.04 OpenSSL Cryptographic Module | Canonical Ltd. | FIPS 140-2 | Review Pending
Ubuntu 20.04 Kernel Crypto API Cryptographic Module | Canonical Ltd. | FIPS 140-2 | Review Pending
Ubuntu 20.04 Libgcrypt Cryptographic Module | Canonical Ltd. | FIPS 140-2 | Review Pending
Ubuntu 20.04 OpenSSL Cryptographic Module | Canonical Ltd. | FIPS 140-2 | Review Pending
Ubuntu 20.04 Strongswan Cryptographic Module | Canonical Ltd. | FIPS 140-2 | Review Pending
Check Point Cryptographic Library | Check Point Software Technologies Ltd. | FIPS 140-2 | Review Pending
Radio Internet-Protocol Communications Module Z (RIC-Mz) | Christine Wireless, Inc. | FIPS 140-2 | Review Pending
Tactical Key Management Device (TKMD) | Christine Wireless, Inc. | FIPS 140-2 | Review Pending
Cisco 8200 Series Routers | Cisco Systems, Inc. | FIPS 140-2 | Review Pending
Cisco 8800 Series Routers | Cisco Systems, Inc. | FIPS 140-2 | Review Pending
Cisco Adaptive Security Appliance (ASA) Virtual | Cisco Systems, Inc. | FIPS 140-2 | Coordination
Cisco Aironet 1562e/i/d/ps, 2802e/i, 3802e/i/p, 4800, IW6300H-AC/DC/DCW Wireless LAN Access Points, Version IOS-XE 17.3 | Cisco Systems, Inc. | FIPS 140-2 | Review Pending
Cisco Aironet 9115AXI/AXE, 9120AXI/AXE/AXP, 9130AXI/AXE, and 9105AXI/AXW Wireless LAN Access Points | Cisco Systems, Inc. | FIPS 140-2 | Review Pending
Cisco ASA and ISA Firepower Threat Defense Cryptographic Modules | Cisco Systems, Inc. | FIPS 140-2 | Coordination
Cisco ASR 1000 Series Routers without MACSEC | Cisco Systems, Inc. | FIPS 140-2 | Coordination
Cisco Catalyst 9200 Series Switches | Cisco Systems, Inc. | FIPS 140-2 | Coordination
Cisco Catalyst 9200L Series Switches | Cisco Systems, Inc. | FIPS 140-2 | Coordination
Cisco Catalyst 9300 Series Switches | Cisco Systems, Inc. | FIPS 140-2 | Coordination
Cisco Catalyst 9400 Series Switches | Cisco Systems, Inc. | FIPS 140-2 | Coordination
Cisco Catalyst 9600 Series Switches | Cisco Systems, Inc. | FIPS 140-2 | Coordination
Cisco Catalyst 9800 (40/80/L) Wireless Controllers running IOS-XE 16.12 | Cisco Systems, Inc. | FIPS 140-2 | Coordination
Cisco Catalyst 9800-CL Wireless Controller | Cisco Systems, Inc. | FIPS 140-2 | Coordination
Cisco Firepower 2100 Cryptographic Module | Cisco Systems, Inc. | FIPS 140-2 | Coordination
Cisco Firepower Threat Defense on 4K/9K Cryptographic Module | Cisco Systems, Inc. | FIPS 140-2 | Coordination
Cisco FTD FX-OS on 4K/9K Cryptographic Module | Cisco Systems, Inc. | FIPS 140-2 | Coordination
Cisco ISR 1000 Series Routers without MACSEC | Cisco Systems, Inc. | FIPS 140-2 | Coordination
Citrix ADC MPX | Citrix Systems, Inc. | FIPS 140-2 | Review Pending
Citrix ADC VPX | Citrix Systems, Inc. | FIPS 140-2 | Review Pending
CliniComp Data Acquisition Cryptographic Module | CliniComp, Intl. | FIPS 140-2 | Review Pending
R650-US Access Point, R650-WW Access Point, R750 Access Point, R850 Access Point, T750SE Access Point, and T750 Access Point | CommScope Technologies LLC | FIPS 140-2 | Review Pending
Ruckus Networks SmartZone 144 (SZ-144) and SmartZone 300 (SZ-300) WLAN Controllers | CommScope Technologies LLC | FIPS 140-2 | Review Pending
Ruckus Networks Virtual SmartZone - Data Plane (vSZ-D) | CommScope Technologies LLC | FIPS 140-2 | Review Pending
Ruckus Networks Virtual SmartZone (vSZ) | CommScope Technologies LLC | FIPS 140-2 | Review Pending
Vocality RoIP and DTECH M3-SE Multi-Function Gateway Appliances | Cubic Corporation | FIPS 140-2 | Review Pending
FSM-2 Flash Storage Cryptographic Module | Curtiss-Wright Controls Defense Solutions | FIPS 140-2 | Review Pending
DL4FE | DataLocker Inc. | FIPS 140-2 | Review Pending
K350 | DataLocker Inc. | FIPS 140-2 | Review Pending
RSA BSAFE(R) Crypto-C Micro Edition | Dell Inc, BSAFE Product Team | FIPS 140-2 | Review Pending
RSA BSAFE(R) Crypto-C Micro Edition | Dell Inc, BSAFE Product Team | FIPS 140-2 | Review Pending
DIGISTOR TCG OPAL SSC FIPS SSD Series | DIGISTOR | FIPS 140-2 | Review Pending
DINAMO CD, XP, and ST Hardware Security Modules | DINAMO Networks, Inc. | FIPS 140-2 | Review Pending
DINAMO Pocket Hardware Security Module | DINAMO Networks, Inc. | FIPS 140-2 | Review Pending
DocuSign HSM Appliance | DocuSign, Inc. | FIPS 140-2 | Coordination
DocuSign Signature Appliance | DocuSign, Inc. | FIPS 140-2 | Coordination
ECI TM200EN Encryption Module | ECI Telecom Ltd. | FIPS 140-2 | Coordination
Johnson Encryption Machine 2 (JEM2) | EF Johnson Technologies | FIPS 140-2 | In Review
Envieta QFlex Hardware Security Module | Envieta Systems LLC | FIPS 140-2 | Review Pending
MS1201 Security Sub-system | eWBM | FIPS 140-2 | Review Pending
Extreme Networks SLX 9640, SLX 9150 and SLX 9250 Switches | Extreme Networks, Inc. | FIPS 140-2 | Review Pending
Extreme® MLXe® Series Ethernet Routers | Extreme Networks, Inc. | FIPS 140-2 | Coordination
Extreme® NetIron® CER 2000 Series Ethernet Routers | Extreme Networks, Inc. | FIPS 140-2 | Review Pending
F5(R) Device Cryptographic Module | F5 Networks, Inc | FIPS 140-2 | Coordination
FEITIAN Biometric FIDO Key Module | FEITIAN Technologies | FIPS 140-2 | Review Pending
OTP Token | FEITIAN Technologies | FIPS 140-2 | Review Pending
FAST C-LIB | Fescaro Co. Ltd. | FIPS 140-2 | Review Pending
FireEye CM Series: CM1500V, CM2500V, CM7500V | FireEye, Inc. | FIPS 140-2 | In Review
FireEye CM Series: CM4500, CM7500, CM9400, CM9500 | FireEye, Inc. | FIPS 140-2 | In Review
FireEye EX Series: EX3500, EX5500, EX8400, EX8500 | FireEye, Inc. | FIPS 140-2 | Review Pending
FireEye EX Series: EX5500V | FireEye, Inc. | FIPS 140-2 | In Review
FireEye HX Series: HX4402, HX4502, HX4502D | FireEye, Inc. | FIPS 140-2 | Review Pending
FireEye HX Series: HX4502V | FireEye, Inc. | FIPS 140-2 | In Review
FireEye NX Series: NX1500, NX2500, NX2550, NX3500, NX4500, NX5500, NX6500 | FireEye, Inc. | FIPS 140-2 | Review Pending
FireEye NX Series: NX1500V, NX2500V, NX2550V, NX4500V, NX6500V | FireEye, Inc. | FIPS 140-2 | In Review
FireEye VX Series: VX5500, VX12500, VX12550 | FireEye, Inc. | FIPS 140-2 | Review Pending
FireEye VX Series: VX7690Vfips | FireEye, Inc. | FIPS 140-2 | In Review
MonocryptAES Enhanced Crypto Library | Focus Systems Corporation | FIPS 140-2 | Coordination
Fortanix SDKMS Appliance | Fortanix, Inc. | FIPS 140-2 | In Review
Fortanix SDKMS Appliance (FX2200, Version 3.10.16) | Fortanix, Inc. | FIPS 140-2 | Coordination
FortiAnalyzer 6.2 | Fortinet, Inc. | FIPS 140-2 | Review Pending
FortiAP-U221EV, FortiAP-U223EV, FortiAP-U321EV, FortiAP-U323EV, FortiAP-U421EV, FortiAP-U422EV, FortiAP-U423EV, FortiAP-U431F and FortiAP-U433F | Fortinet, Inc. | FIPS 140-2 | Review Pending
FortiGate-1101E/2000E/2201E/2500E/3301E | Fortinet, Inc. | FIPS 140-2 | Coordination
FortiGate-201E/301E/401E/501E/601E | Fortinet, Inc. | FIPS 140-2 | Review Pending
FortiGate-3401E/3601E/3960E/3980E | Fortinet, Inc. | FIPS 140-2 | Coordination
FortiGate-5001E1 Blade with FortiGate-5144C Chassis | Fortinet, Inc. | FIPS 140-2 | Review Pending
FortiGate-600D/1200D/1500D/3000D/3700D and FortiGate-5001D with FortiGate-5144C Chassis | Fortinet, Inc. | FIPS 140-2 | Review Pending
FortiGate-61E/61F/81E/101E/101F and FortiWiFi-61E | Fortinet, Inc. | FIPS 140-2 | In Review
FortiGate-6300F/6301F/6500F/6501F | Fortinet, Inc. | FIPS 140-2 | Review Pending
FortiGate-VM | Fortinet, Inc. | FIPS 140-2 | Review Pending
FortiManager 6.2 | Fortinet, Inc. | FIPS 140-2 | Review Pending
FortiSandbox-1000F/2000E/3000E | Fortinet, Inc. | FIPS 140-2 | Review Pending
FortiWLC-50D/500D/1000D/3000D | Fortinet, Inc. | FIPS 140-2 | Coordination
FortiWLM-100D and FortiWLM-1000D | Fortinet, Inc. | FIPS 140-2 | Coordination
EXP1000 Hardware Security Module | Futurex | FIPS 140-2 | Review Pending
GSP3000 Hardware Security Module | Futurex | FIPS 140-2 | Review Pending
Fortress Mesh Points | General Dynamics Mission Systems | FIPS 140-2 | Coordination
GigaVUE-HC2 Visibility Appliance | Gigamon Inc. | FIPS 140-2 | Coordination
GigaVUE-HC3 Visibility Appliance | Gigamon Inc. | FIPS 140-2 | Coordination
Titan Security Key, Chip Boundary | Google, LLC. | FIPS 140-2 | In Review
HID Global Applets v3.0 on NXP JCOP 3 SecID P60 CS (OSB) | HID Global | FIPS 140-2 | Coordination
HID Global Applets v3.0 on NXP JCOP 3 SecID P60 CS (OSB) | HID Global | FIPS 140-2 | Coordination
Hitachi Virtual Storage Platform (VSP) Encryption Board for NVMe | Hitachi, Ltd. | FIPS 140-2 | Review Pending
HUAWEI OptiX OSN 1800 Series | Huawei Technologies Co., Ltd. | FIPS 140-2 | Coordination
Hub Security Cryptographic Module | Hub Security LTD | FIPS 140-2 | Review Pending
HyTrust KeyControl Cryptographic Module | HyTrust, Inc. | FIPS 140-2 | Review Pending
IBM 4769-001 Cryptographic Coprocessor Security Module | IBM Corporation | FIPS 140-2 | Coordination
IBM(R) Security QRadar(R) Cryptographic Security Kernel | IBM Corporation | FIPS 140-2 | Coordination
IBM(R) z/OS(R) Version 2 Release 4 ICSF PKCS #11 Cryptographic Module | IBM Corporation | FIPS 140-2 | Review Pending
IBM(R) z/OS(R) Version 2 Release 4 ICSF PKCS #11 Cryptographic Module | IBM Corporation | FIPS 140-2 | Coordination
IBM(R) z/OS(R) Version 2 Release 4 System SSL Cryptographic Module | IBM Corporation | FIPS 140-2 | Review Pending
IBM(R) z/OS(R) Version 2 Release 4 System SSL Cryptographic Module | IBM Corporation | FIPS 140-2 | Coordination
IBM(R) z/VM(R) Version 7 Release 2 System SSL Cryptographic Module | IBM Corporation | FIPS 140-2 | Review Pending
IBM(R) NVMe FlashCore(TM) Module 2 | IBM(R) Corporation | FIPS 140-2 | Coordination
mTera 8-slot Universal Transport Platform | Infinera Corporation | FIPS 140-2 | Coordination
Integral AES 256 Bit Crypto SSD Underlying PCB | Integral Memory Plc | FIPS 140-2 | Coordination
Integral Crypto AES 256 Bit USB 3.0 | Integral Memory Plc | FIPS 140-2 | Coordination
Cryptographic Module for Intel(R) Converged Security and Manageability Engine (CSME) for Intel Tiger Point PCH | Intel Corporation | FIPS 140-2 | Review Pending
Cryptographic Module for Intel(R) Converged Security and Manageability Engine(CSME) | Intel Corporation | FIPS 140-2 | Review Pending
Cryptographic Module for Intel® Platforms' Security Engine Chipset | Intel Corporation | FIPS 140-2 | Coordination
Cryptographic Module for Intel® Platforms' Security Engine Chipset | Intel Corporation | FIPS 140-2 | Coordination
Intel(R) Offload and Crypto Subsystem (OCS) | Intel Corporation | FIPS 140-2 | Review Pending
IQVIA Java Crypto Module | IQVIA | FIPS 140-2 | Review Pending
iStorage datAshur BT | iStorage Ltd. | FIPS 140-2 | Review Pending
Juniper Kernel Crypto Cryptographic Module | Juniper Networks | FIPS 140-2 | Review Pending
Juniper OpenSSL Cryptographic Module | Juniper Networks | FIPS 140-2 | Review Pending
Juniper Networks ACX5448-M Router | Juniper Networks, Inc | FIPS 140-2 | Review Pending
Juniper Networks EX4650, QFX5120 and QFX5210 Ethernet Switches | Juniper Networks, Inc | FIPS 140-2 | Review Pending
Juniper Networks SRX345, SRX345-DUAL-AC, SRX380 and SRX1500 Services Gateway | Juniper Networks, Inc | FIPS 140-2 | Review Pending
Juniper Networks EX4300-48MP Ethernet Switch | Juniper Networks, Inc. | FIPS 140-2 | Coordination
Juniper Networks MX10003 3D Universal Edge Router with JNP-MIC1-MACSEC MACSec MIC and EX9253 Ethernet Switch with EX9253-6Q12C-M MACSec Line Card | Juniper Networks, Inc. | FIPS 140-2 | Coordination
Juniper Networks MX104 3D Universal Edge Router with the Multiservices MIC | Juniper Networks, Inc. | FIPS 140-2 | Coordination
Juniper Networks MX240, MX480, MX960 3D Universal Edge Routers and EX9204, EX9208, EX9214 Ethernet Switches with RE-S-X6-64G/RE-S-X6-128G/EX9200-RE2 Routing Engine and MPC7E-10G/EX9200-40XS MACsec Card | Juniper Networks, Inc. | FIPS 140-2 | Coordination
Juniper Networks MX240, MX480, MX960 3D Universal Edge Routers with RE1800 Routing Engine and MPC7E-10G MACsec Card | Juniper Networks, Inc. | FIPS 140-2 | Coordination
Juniper Networks MX240, MX480, MX960 3D Universal Edge Routers with RE1800 Routing Engine and Multiservices MPC | Juniper Networks, Inc. | FIPS 140-2 | Coordination
Juniper Networks MX240, MX480, MX960 3D Universal Edge Routers with RE-S-X6-64G Routing Engine and Multiservices MPC | Juniper Networks, Inc. | FIPS 140-2 | Coordination
Juniper Networks NFX250 Network Services Platform | Juniper Networks, Inc. | FIPS 140-2 | In Review
Defender HDD 300 | Kanguru Solutions | FIPS 140-2 | Review Pending
KIOXIA TCG Enterprise SSC Crypto Sub-Chip TC58NC1132GTC | KIOXIA Corporation | FIPS 140-3 | Review Pending
KIOXIA TCG Enterprise SSC Crypto Sub-Chip TC58NC1132GTC | KIOXIA Corporation | FIPS 140-2 | Review Pending
KIOXIA TCG OPAL SSC Crypto Sub-Chip TC58NC1132GTC | KIOXIA Corporation | FIPS 140-2 | Review Pending
MFP Cryptographic Module(A) | Kyocera Document Solutions Inc. | FIPS 140-2 | Review Pending
RF-7800W Broadband Ethernet Radio | L3Harris Technologies, Inc. | FIPS 140-2 | Review Pending
ESCRYPT's CycurLIB | Landis+Gyr | FIPS 140-2 | Coordination
Macronix ArmorFlash MX78 series | Macronix International Co., Ltd. | FIPS 140-2 | Review Pending
AEDS | Maxar Technologies | FIPS 140-2 | Review Pending
Network Security Platform Sensor NS3100, NS3200, NS5100 and NS5200 | McAfee, LLC | FIPS 140-2 | Coordination
Network Security Platform Sensor NS7100, NS7200 and NS7300 | McAfee, LLC | FIPS 140-2 | Coordination
Network Security Platform Sensor NS7150, NS7250 and NS7350 | McAfee, LLC | FIPS 140-2 | Coordination
Network Security Platform Sensor NS7500 | McAfee, LLC | FIPS 140-2 | Review Pending
Network Security Platform Sensor NS9100 and NS9200 | McAfee, LLC | FIPS 140-2 | Coordination
Network Security Platform Sensor NS9300 S | McAfee, LLC | FIPS 140-2 | Coordination
Network Security Platform Sensor NS9300P | McAfee, LLC | FIPS 140-2 | Coordination
NV-2108 Flashtec(TM) PCIe NVRAM Drive | Microchip Technology, Inc. | FIPS 140-2 | Review Pending
BitLocker Dump Filter | Microsoft Corporation | FIPS 140-2 | Review Pending
BitLocker Dump Filter | Microsoft Corporation | FIPS 140-2 | Review Pending
Boot Manager | Microsoft Corporation | FIPS 140-2 | Review Pending
Boot Manager | Microsoft Corporation | FIPS 140-2 | Coordination
Code Integrity | Microsoft Corporation | FIPS 140-2 | Review Pending
Code Integrity | Microsoft Corporation | FIPS 140-2 | Review Pending
Cryptographic Primitives Library | Microsoft Corporation | FIPS 140-2 | Review Pending
Cryptographic Primitives Library | Microsoft Corporation | FIPS 140-2 | Review Pending
Kernel Mode Cryptographic Primitives Library | Microsoft Corporation | FIPS 140-2 | Review Pending
Secure Kernel Code Integrity | Microsoft Corporation | FIPS 140-2 | Review Pending
Secure Kernel Code Integrity | Microsoft Corporation | FIPS 140-2 | Review Pending
TCB Launcher | Microsoft Corporation | FIPS 140-2 | Review Pending
Virtual TPM | Microsoft Corporation | FIPS 140-2 | Review Pending
Virtual TPM | Microsoft Corporation | FIPS 140-2 | Review Pending
Windows OS Loader | Microsoft Corporation | FIPS 140-2 | Review Pending
Windows OS Loader | Microsoft Corporation | FIPS 140-2 | Review Pending
Windows Resume | Microsoft Corporation | FIPS 140-2 | Review Pending
FIPS AP43 | Mist Systems | FIPS 140-2 | Coordination
Command Encryption Module | Mitsubishi Space Software Co., Ltd. | FIPS 140-2 | Review Pending
Mocana Cryptographic Loadable Kernel Module | Mocana Corporation | FIPS 140-2 | Review Pending
Mocana Cryptographic Suite B Module | Mocana Corporation | FIPS 140-2 | Review Pending
Mocana Cryptographic Suite B Module | Mocana Corporation | FIPS 140-2 | Review Pending
µMACE | Motorola Solutions, Inc. | FIPS 140-2 | Review Pending
Astro Subscriber Motorola Advanced Crypto Engine (MACE) - Security Level 2 | Motorola Solutions, Inc. | FIPS 140-2 | Review Pending
Astro Subscriber Motorola Advanced Crypto Engine (MACE) - Security Level 2 | Motorola Solutions, Inc. | FIPS 140-2 | Coordination
Astro Subscriber Motorola Advanced Crypto Engine (MACE) - Security Level 3 | Motorola Solutions, Inc. | FIPS 140-2 | Review Pending
Astro Subscriber Motorola Advanced Crypto Engine (MACE) - Security Level 3 | Motorola Solutions, Inc. | FIPS 140-2 | Coordination
Motorola GGM 8000 Gateway | Motorola Solutions, Inc. | FIPS 140-2 | Review Pending
Motorola Network Router (MNR) S6000 | Motorola Solutions, Inc. | FIPS 140-2 | Review Pending
Motorola Solutions Cryptographic Firmware Module | Motorola Solutions, Inc. | FIPS 140-2 | Review Pending
Motorola Solutions Cryptographic Firmware Module | Motorola Solutions, Inc. | FIPS 140-2 | Coordination
Motorola Solutions Cryptographic Firmware Module | Motorola Solutions, Inc. | FIPS 140-2 | Coordination
NetApp CryptoMod | NetApp, Inc. | FIPS 140-2 | Review Pending
NETSCOUT FIPS Object Module | NETSCOUT Systems, Inc. | FIPS 140-2 | Review Pending
7705 SAR-OS SAR-18/8/X/Ax/Wx/W/H/Hc Control Plane Cryptographic Module (SARCPCM) | Nokia Corporation | FIPS 140-2 | Review Pending
7705 SAR-OS SAR-18/8/X/Ax/Wx/W/H/Hc Data Plane Cryptographic Module (SARDPCM) | Nokia Corporation | FIPS 140-2 | Review Pending
7705 SAR-OS SAR-A/M Cryptographic Module (SARCM) | Nokia Corporation | FIPS 140-2 | Review Pending
Nokia 1830 Photonic Service Switch (PSS) | Nokia Corporation | FIPS 140-2 | Coordination
SR-OS Cryptographic Module | Nokia Corporation | FIPS 140-2 | Review Pending
NPCT7xx TPM 2.0 rev 1.38 | Nuvoton Technology Corporation | FIPS 140-2 | Coordination
FIPS SE051 | NXP Semiconductors | FIPS 140-2 | Review Pending
i.MX 8X SECO HSM | NXP Semiconductors | FIPS 140-2 | Review Pending
SE050 | NXP Semiconductors | FIPS 140-2 | Coordination
Acme Packet 4600 and Acme Packet 6300 and Acme Packet 6350 | Oracle Communications | FIPS 140-2 | Review Pending
Oracle Linux Unbreakable Enterprise Kernel (UEK 5) Cryptographic Module | Oracle Corporation | FIPS 140-2 | Coordination
Oracle Linux Unbreakable Enterprise Kernel (UEK) Cryptographic Module | Oracle Corporation | FIPS 140-2 | Coordination
Oracle Solaris Kernel Cryptographic Framework | Oracle Corporation | FIPS 140-2 | Review Pending
Oracle Solaris Userland Cryptographic Framework | Oracle Corporation | FIPS 140-2 | Review Pending
OSNEXUS Crypto Library | OSNEXUS Corporation | FIPS 140-2 | Review Pending
GlobalProtect App | Palo Alto Networks | FIPS 140-2 | Review Pending
Instant-On Networks (ION) devices ION 1000, ION 2000, ION 3000, ION 7000, and ION 9000 | Palo Alto Networks, Inc. | FIPS 140-2 | Review Pending
Panorama 9.0 M-100, M-200, M-500 and M-600 | Palo Alto Networks, Inc. | FIPS 140-2 | Coordination
Panorama Virtual Appliance 9.0 | Palo Alto Networks, Inc. | FIPS 140-2 | Coordination
PAN-OS 9.0 Firewalls PA-220, PA-220R, PA-800 Series, PA-3000 Series, PA-3200 Series, PA-5200 Series, and PA-7000 Series | Palo Alto Networks, Inc. | FIPS 140-2 | Coordination
PAN-OS 9.0 VM-Series | Palo Alto Networks, Inc. | FIPS 140-2 | Coordination
WildFire 9.0 WF-500 | Palo Alto Networks, Inc. | FIPS 140-2 | Coordination
Pavilion Cryptographic Module | Pavilion Data Systems | FIPS 140-2 | Review Pending
X4i Hardware Security Module (HSM) | Pitney Bowes, Inc. | FIPS 140-2 | Coordination
X4i Postal Security Device (PSD) | Pitney Bowes, Inc. | FIPS 140-2 | Review Pending
Poly Unified Communications Cryptographic Module | Plantronics, Inc. | FIPS 140-2 | Coordination
ENFORCER R1 | Private Machines Inc. | FIPS 140-2 | Coordination
Purity Encryption Module | Pure Storage, Inc. | FIPS 140-2 | Review Pending
CMS-5000 | QSC, LLC | FIPS 140-2 | Coordination
Quadient Postal Security Device (PSD) | Quadient Technologies France | FIPS 140-2 | Review Pending
Qualcomm(R) Crypto Engine Core | Qualcomm Technologies, Inc. | FIPS 140-2 | Review Pending
Qualcomm(R) Secure Processing Unit (SPU) Random Number Generator (RNG) | Qualcomm Technologies, Inc. | FIPS 140-2 | Review Pending
VaultIP | Rambus Inc. | FIPS 140-2 | Coordination
Red Hat Enterprise Linux 7 Kernel Crypto API Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 | Coordination
Red Hat Enterprise Linux 7 NSS Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 | Coordination
Red Hat Enterprise Linux 7 OpenSSH Client Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 | Coordination
Red Hat Enterprise Linux 7 OpenSSH Server Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 | Coordination
Red Hat Enterprise Linux 7 OpenSSL Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 | Coordination
Red Hat Enterprise Linux 8 GnuTLS Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 | Review Pending
Red Hat Enterprise Linux 8 Kernel Crypto API Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 | Review Pending
Red Hat Enterprise Linux 8 NSS Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 | Review Pending
Red Hat Enterprise Linux 8 NSS Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 | Coordination
Red Hat Enterprise Linux 8 OpenSSL Cryptographic Module | Red Hat(R), Inc. | FIPS 140-2 | Coordination
SBC 5400 Session Border Controller | Ribbon Communications, Inc. | FIPS 140-2 | Coordination
RSA BSAFE(R) Crypto Module | RSA | FIPS 140-2 | In Review
RSA BSAFE(R) Crypto-C Micro Edition | RSA Security, LLC | FIPS 140-2 | Coordination
Ruckus Networks Virtual Smart Zone (vSZ) | Ruckus Wireless, Inc. | FIPS 140-2 | Coordination
Ruckus Networks Virtual SmartZone - Data Plane (vSZ-D) | Ruckus Wireless, Inc. | FIPS 140-2 | Coordination
Samsung NVMe TCG Opal SSC SEDs PM1733 Series | Samsung Electronics Co., Ltd. | FIPS 140-2 | Review Pending
Samsung SAS 12G TCG Enterprise SSC SEDs PM1643a Series | Samsung Electronics Co., Ltd. | FIPS 140-2 | Review Pending
CN Series Encryptors | Senetas Corporation Ltd., distributed by Thales SA (SafeNet) | FIPS 140-2 | Coordination
CN6000 Series Encryptors | Senetas Corporation Ltd., distributed by Thales SA (SafeNet) | FIPS 140-2 | Coordination
SX-590-1402 | silex technology, Inc. | FIPS 140-2 | Review Pending
Silver Peak ECOS Cryptographic Library | Silver Peak Systems Inc. | FIPS 140-2 | Review Pending
SonicWall Network Security Virtual Appliances | SonicWall, Inc. | FIPS 140-2 | Review Pending
SonicWALL NSsp 14700 and NSsp 15700 | SonicWall, Inc. | FIPS 140-2 | Review Pending
SonicWALL TZ270, TZ270W, TZ370, TZ370W, TZ470, TZ470W, TZ570, TZ570W, TZ570P, TZ670 and NSa 2700 | SonicWall, Inc. | FIPS 140-2 | Review Pending
SUSE Linux Enterprise Kernel Crypto API Cryptographic Module | SUSE, LLC | FIPS 140-2 | Review Pending
SUSE Linux Enterprise Kernel Crypto API Cryptographic Module | SUSE, LLC | FIPS 140-2 | Review Pending
SUSE Linux Enterprise OpenSSL Cryptographic Module | SUSE, LLC | FIPS 140-2 | Review Pending
SUSE Linux Enterprise Server GnuTLS Cryptographic Module | SUSE, LLC | FIPS 140-2 | Review Pending
SUSE Linux Enterprise Server libgcrypt Cryptographic Module | SUSE, LLC | FIPS 140-2 | Coordination
SUSE Linux Enterprise Server libgcrypt Cryptographic Module | SUSE, LLC | FIPS 140-2 | Coordination
SUSE Linux Enterprise Server Libica Cryptographic Module | SUSE, LLC | FIPS 140-2 | Review Pending
SUSE Linux Enterprise Server NSS Cryptographic Module | SUSE, LLC | FIPS 140-2 | Coordination
SUSE Linux Enterprise Server OpenSSL Cryptographic Module | SUSE, LLC | FIPS 140-2 | Coordination
Taglio PIV Applet v2.1 on NXP JCOP 3 SecID P60 CS (OSB) | Taglio | FIPS 140-2 | Review Pending
ProtectServer Internal Express 2 (PSI-E2) | Thales | FIPS 140-2 | Review Pending
ProtectServer PCIe HSM 3 | Thales | FIPS 140-2 | Review Pending
Thales Luna Backup HSM Cryptographic Module | Thales | FIPS 140-2 | Review Pending
Thales Luna K7 Cryptographic Module | Thales | FIPS 140-2 | Coordination
Vormetric Transparent Encryption Cryptographic Module | Thales | FIPS 140-2 | Coordination
Thales Alenia Space cryptographic module for Microsemi RTAX FPGA | Thales Alenia Space | FIPS 140-2 | Review Pending
Luna T7 Cryptographic Module | Thales Trusted Cyber Technologies | FIPS 140-2 | Coordination
TW-900/950 TSM Shadow and TW-870/875 TSM Ghost | TrellisWare Technologies, Inc. | FIPS 140-2 | Review Pending
TippingPoint Crypto Core OpenSSL | Trend Micro Inc. | FIPS 140-2 | Coordination
UD info DA-series FIPS SSD | UD info Corp. | FIPS 140-2 | Review Pending
Unisys Linux Kernel Cryptographic API Module | Unisys Corporation | FIPS 140-2 | Coordination
Unisys Linux strongSwan Cryptographic Module | Unisys Corporation | FIPS 140-2 | Coordination
Unisys OpenSSL Linux Cryptographic Module | Unisys Corporation | FIPS 140-2 | In Review
CERDEC Cryptographic Module | US Army CERDEC | FIPS 140-2 | Review Pending
CryptoServer CSe-Series | Utimaco IS GmbH | FIPS 140-2 | Coordination
CryptoServer Se-Series Gen2 | Utimaco IS GmbH | FIPS 140-2 | Coordination
u.trust ANCHOR CSAR | Utimaco IS GmbH | FIPS 140-2 | Review Pending
RAD X-1040 AES-256 | Vcinity, Inc. | FIPS 140-2 | Review Pending
Vidyo Cryptographic Security Kernel | Vidyo, Inc. | FIPS 140-2 | Coordination
Virtru JavaScript Cryptographic Library | Virtru Corporation | FIPS 140-2 | Review Pending
VMware’s Linux Cryptographic Module | VMware, Inc. | FIPS 140-2 | Coordination
VMware's SD-WAN VPN Crypto Module | VMware, Inc. | FIPS 140-2 | Review Pending
VMware's SD-WAN VPN Hybrid Crypto Module | VMware, Inc. | FIPS 140-2 | Review Pending
Vocera Cryptographic Module v3.1 | Vocera Communications, Inc. | FIPS 140-2 | Review Pending
Vocera Smartbadge Cryptographic Module | Vocera Communications, Inc. | FIPS 140-2 | Coordination
WatchKey ProX USB Token Cryptographic Module | WatchData Technologies Pte Ltd | FIPS 140-2 | Review Pending
Ultrastar® DC HC330 TCG Enterprise HDD | Western Digital Corporation | FIPS 140-2 | Coordination
Ultrastar® DC HC550 TCG Enterprise HDD | Western Digital Corporation | FIPS 140-2 | Review Pending
Ultrastar® He¹° and Ultrastar® DC HC510 TCG Enterprise HDD | Western Digital Corporation | FIPS 140-2 | Review Pending
Ultrastar® He¹² and Ultrastar® DC HC520 TCG Enterprise HDD | Western Digital Corporation | FIPS 140-2 | Review Pending
YubiHSM 2 Cryptographic Module (Level 3) | Yubico, Inc. | FIPS 140-2 | Coordination
YubiKey 5 Cryptographic Module | Yubico, Inc. | FIPS 140-2 | Coordination
YubiKey 5 Cryptographic Module | Yubico, Inc. | FIPS 140-2 | Coordination
DHSSL Cryptographic Module | Zhejiang Dahua Technology Co., Ltd. | FIPS 140-2 | Review Pending
Displayed | 303
Not Displayed | 27
Total | 330

Created October 11, 2016, Updated January 26, 2021